@@ -14,7 +14,12 @@ const project = new CdklabsConstructLibrary({
   defaultReleaseBranch: 'main',
   repositoryUrl: 'https://github.com/cdklabs/cdk-pipelines-github.git',
   bundledDeps: ['decamelize', 'yaml', 'fast-json-patch'],
-  devDeps: ['cdklabs-projen-project-types@^0.0.9', 'aws-cdk-lib'],
+  devDeps: [
+    'cdklabs-projen-project-types@^0.0.9',
+    'aws-cdk-lib',
+    '@aws-cdk/integ-runner@^2.60.0',
+    '@aws-cdk/integ-tests-alpha',
+  ],
   peerDeps: ['aws-cdk-lib'],
   jestOptions: {
     updateSnapshot: UpdateSnapshot.NEVER,
